@@ -50,6 +50,15 @@ ZDBConnection::~ZDBConnection()
 ShutDown();
 }
 
+void ZDBConnection::FreeFields()
+{
+for(int i=0;i<MAXFLDLIST;i++)	{
+	if(Field[i]!=NULL)
+		delete(Field[i]);
+	}
+return;
+}
+
 //****************************************************************************
 //				ShutDown
 //****************************************************************************
