@@ -1,23 +1,40 @@
 #include "zmsql.h"
 
 #define NUM_SQLS 2
-
+#define SERVER "localhost" 
+#define DATABASE "test"
+#define TABLE "zmsqltest"
 
 main()
 {
 int NumFlds;
+int NumDBs,NumTables;
 char result[1000];
 int i,j,k;
 char data[2048];
 ZField FldInfo;
 int minid=70,maxid=75;
 char namelike[]="item";
+ZDBList DBList;
+ZTableList TableList;
 
 ZmSQLConnection TestDB;
 ZmSQL sql(&TestDB);
-TestDB.SetServer(NULL);
-TestDB.SetDB("test");
-if(!sql.Open("select * from test where num > %d and num < %d and name LIKE '%%%s%%'",minid,maxid,namelike))	{
+NumDBs=TestDB.GetDBList(SERVER,DBList);
+NumTables=TestDB.GetTableList(SERVER,DATABASE,TableList);
+printf("Databases on %s\n****************\n",SERVER);
+for(i=0;i<NumDBs;i++)	
+	printf("%s\n",DBList[i]);
+printf("Tables in \"%s\" on %s\n****************\n",DATABASE,SERVER);
+for(i=0;i<NumTables;i++)	
+	printf("%s\n",TableList[i]);
+TestDB.SetServer(SERVER);
+TestDB.SetDB(DATABASE);
+printf("Fields in '%s'\n********************\n",DATABASE);
+i=0;
+while(TestDB.Field[i])	
+	printf("%s\n",TestDB.Field[i++]->Name);
+if(!sql.Open("select * from %s where num > %d and num < %d and name LIKE '%%%s%%'",TABLE,minid,maxid,namelike))	{
 	printf("Error opening sql\n");
 	return 0;
 	}
