@@ -21,18 +21,19 @@ class  ZmSQL : public ZSQL	{
 		int Open(char*,...);
 		void Close();
 		int GetSQLData(int,char*,int);
-                int GetSQLData(int,int*);
-                int GetSQLData(int,float*);
+		int GetSQLData(int,int*);
+		int GetSQLData(int,float*);
+		int GetSQLData(int,double*);
   		int GetNextRecord();
 		int GetFieldInfo(int,ZField*);
 		int GetNumCols();
 		int GetNumRows();
-		void PrintError(int=TO_LOG);
 		void Initialize();
 		long Max(char* table,char* fld,char* Where=NULL);
 		long Min(char* table,char* fld,char* Where=NULL);
 		long Count(char* table,char* Where=NULL);
 		char* GetError(){return msqlErrMsg;}
+		virtual void PrintError();
 		};
 	
 class  ZmSQLConnection	:public ZDBConnection{
@@ -50,6 +51,9 @@ class  ZmSQLConnection	:public ZDBConnection{
 		virtual BOOL SetServer(char*);
 		virtual char* GetDBName(int);
 		char* GetError(){return msqlErrMsg;}
+		int GetDBList(char *,ZDBList);
+		int GetDBInfo(char *,char *pDB,ZField**);
+		int GetTableList(char* pServer,char* pDB,ZTableList);
 	};
 
 #endif
